@@ -356,12 +356,12 @@ void cmdline(int argc, char *argv[])
  **/
 void sigchld_handler(int s)
 {
-        int* status=NULL;
+        int status;
 	int i;
 	char buf[80];
 	pid_t pid;
 
-	while((pid=wait(status)) > 0) {
+	while ((pid = waitpid(-1, &status, WNOHANG)) > 0) {
 		if(WIFEXITED(status)) {
 			memset(buf,'\0', 80);
 			snprintf(buf, 79, "%d", WEXITSTATUS(status));
